CodedLists

Struct CodedLists 

pub struct CodedLists {
    pub next: Option<Box<CodedLists>>,
    pub buf: *mut u8,
    pub buf_size: usize,
    pub avail: bool,
}
A node in a singly-linked list of coded data buffers — port of coded_lists.

Fields

next: Option<Box<CodedLists>>

Pointer to the next node, or None if this is the tail.

buf: *mut u8

Pointer to the start of the coded data in this node.

buf_size: usize

Number of valid coded bytes.

avail: bool

True when the list is not ready for consumption.

Implementations

Source

impl CodedLists

pub fn new() -> Self

Creates a new, empty coded-list node.