LineBuf

Struct LineBuf 

pub struct LineBuf {
    pub size: usize,
    pub pre_size: u32,
    pub flags: u32,
    pub data: LineBufData,
}
A single line (row) of sample data used throughout the wavelet and coding pipeline — port of the C++ line_buf.

The pointer stored in data is not owned by this struct; it borrows from an arena allocator.

Fields

size: usize

Number of samples in this line.

pre_size: u32

Extra samples prepended before the line (for filter padding).

flags: u32

Combination of LFT_* flag constants describing the element type.

data: LineBufData

Pointer into the backing buffer.

Implementations

Source

impl LineBuf

pub fn new() -> Self

Creates a new, empty line buffer.