Module message

Module message 

Message handling system — port of ojph_message.h/cpp.

The C++ library uses a global mutable message handler with three severity levels. This module provides a similar mechanism using a trait object behind a std::sync::Mutex.

Enums

MsgLevel
Message severity level.

Traits

MessageHandler
Trait for receiving diagnostic messages from the codec.

Functions

dispatch_message
Dispatches a message to the currently installed handler.
set_message_handler
Replaces the global message handler.