pub struct BitBufferRead<'a> { /* private fields */ }Expand description
Bit-level reader with JPEG 2000 0xFF byte-unstuffing.
Reads from a byte slice, automatically handling the rule that after a 0xFF byte the MSB of the next byte is ignored (stuffed).
Implementations
Sourceimpl<'a> BitBufferRead<'a>
impl<'a> BitBufferRead<'a>
Sourcepub fn available_bits(&self) -> u32
pub fn available_bits(&self) -> u32
Returns the number of valid bits currently in the buffer.
Sourcepub fn is_unstuffing(&self) -> bool
pub fn is_unstuffing(&self) -> bool
Returns true if the previous byte read was 0xFF.