pub struct CodedLists {
pub next: Option<Box<CodedLists>>,
pub buf: *mut u8,
pub buf_size: usize,
pub avail: bool,
}Expand description
A node in a singly-linked list of coded data buffers — port of
coded_lists.
Fields
next: Option<Box<CodedLists>>Pointer to the next node, or None if this is the tail.
buf: *mut u8Pointer to the start of the coded data in this node.
buf_size: usizeNumber of valid coded bytes.
avail: boolTrue when the list is not ready for consumption.
Implementations
Sourceimpl CodedLists
impl CodedLists