Message handling system — port of ojph_message.h/cpp.
The C++ library uses a global mutable message handler with three severity
levels. This module provides a similar mechanism using a trait object
behind a std::sync::Mutex.
Enums
- MsgLevel
- Message severity level.
Traits
- Message
Handler - Trait for receiving diagnostic messages from the codec.
Functions
- dispatch_
message - Dispatches a message to the currently installed handler.
- set_
message_ handler - Replaces the global message handler.